import Image from '../Image';
import { OssImageProps } from './types';
import './style.less';
export default {
  name: 'EOssImage',
  "extends": Image,
  props: OssImageProps,
  data: function data() {
    return {
      ossNameToSign: '',
      // 待签名的url
      ossRealUrl: '' // 签名后的url

    };
  },
  watch: {
    // 当ossClient初始化完成后，开始处理预置数据
    ossClient: function ossClient() {
      this._sign();
    },
    // url属性变更，赋值
    url: function url(newVal) {
      if (newVal) {
        this.$data.ossNameToSign = newVal;

        this._sign();
      }
    }
  },
  mounted: function mounted() {
    this.$data.ossNameToSign = this.$props.url;

    this._sign();
  },
  methods: {
    /**
     * 获取图片的显示绝对路径
     * @returns {*}
     * @private
     */
    _getImageTargetUrl: function _getImageTargetUrl() {
      return this.$data.ossRealUrl;
    },

    /**
     * 签名
     * @private
     */
    _sign: function _sign() {
      var _this = this;

      // 如果已经有了oss的真实路径了则不继续操作
      if (this.$data.ossRealUrl) {
        return;
      }

      if (this.ossClient !== undefined && this.$data.ossNameToSign) {
        this.$data.ossRealUrl = this.ossClient.signatureUrl(this.$data.ossNameToSign);
        setTimeout(function () {
          if (!_this.$data.loadImageSuccess) {
            _this._loadingFinish(false);
          }
        }, this.$props.timeout);
      }
    }
  }
};