"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _types = require("./types");

var _card = _interopRequireDefault(require("ant-design-vue/es/card"));

var _descriptions = _interopRequireDefault(require("ant-design-vue/es/descriptions"));

var _DictText = _interopRequireDefault(require("../DictText"));

var _Image = _interopRequireDefault(require("../Image"));

var _OssImage = _interopRequireDefault(require("../OssImage"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

var ADescriptionsItem = _descriptions["default"].Item;
var _default = {
  name: 'EDetailInfo',
  props: _types.DetailProps,
  computed: {
    colProp: function colProp() {
      if (typeof this.column === 'number') {
        return {
          xs: 1,
          sm: 1,
          md: this._getColumn(2),
          lg: this._getColumn(2),
          xl: this._getColumn(3),
          xxl: this._getColumn(4)
        };
      } else {
        return this.column;
      }
    }
  },
  methods: {
    /**
     * 获取列宽
     * @param max 最大可取的值
     * @returns {string|number}
     * @private
     */
    _getColumn: function _getColumn() {
      var max = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 1;
      return this.column > max ? max : this.column;
    },

    /**
     * 获取文字的值
     * @param item
     * @returns {string|*|T|string}
     * @private
     */
    _getItemValue: function _getItemValue(item) {
      if (item.getValue) {
        return item.getValue(this.data[item.key], this.data);
      }

      if (this.data && this.data[item.key]) {
        return this.data[item.key];
      } else {
        return item.defaultValue === undefined ? '-' : item.defaultValue;
      }
    },

    /**
     * 获取枚举的值
     * @param item
     * @returns {string|*}
     * @private
     */
    _getEnumValue: function _getEnumValue(item) {
      if (this.data && this.data[item.key]) {
        var value = this.data[item.key];

        if (item.enumList) {
          var valueObj = item.enumList.find(function (enumItem) {
            return enumItem.value === value;
          });
          return valueObj ? valueObj.label : value;
        }
      }

      return item.defaultValue === undefined ? '-' : item.defaultValue;
    },

    /**
     * 获取图片的值
     * @param item
     * @returns {*}
     * @private
     */
    _getImgValue: function _getImgValue(item) {
      return this.data && this.data[item.key] || item.defaultValue;
    },

    /**
     * 渲染字典类型的文字
     * @private
     */
    _renderDictText: function _renderDictText(item, value) {
      var h = this.$createElement;
      return h(_DictText["default"], {
        attrs: {
          dictId: item.dictId,
          name: value
        }
      });
    },

    /**
     * 渲染文字部分的ui
     * @returns {JSX.Element}
     * @private
     */
    _renderInfoList: function _renderInfoList() {
      var _this = this;

      var h = this.$createElement;
      var list = [];
      this.$props.infoList.forEach(function (item) {
        var value = _this._getItemValue(item);

        if (value) {
          var valueDom;

          switch (item.type) {
            case _types.EASY_DETAIL_TYPE.DICT:
              valueDom = h(_DictText["default"], {
                attrs: {
                  dictId: item.dictId,
                  name: value
                }
              });
              break;

            case _types.EASY_DETAIL_TYPE.ENUM:
              valueDom = _this._getEnumValue(item);
              break;

            case _types.EASY_DETAIL_TYPE.TEXT:
              valueDom = value;
              break;

            case _types.EASY_DETAIL_TYPE.IMAGE:
              valueDom = _this._renderSupportForImgList(item);
              break;

            default:
              var scopeSlot = _this.$scopedSlots[item.key];
              valueDom = scopeSlot ? scopeSlot({
                value: value,
                data: _this.$props.data
              }) : value;
              break;
          }

          list.push(h(ADescriptionsItem, {
            attrs: {
              label: item.title
            }
          }, [valueDom]));
        }
      });
      return h(_descriptions["default"], {
        attrs: {
          column: this.colProp,
          title: this.$props.infoTitle
        }
      }, [list]);
    },

    /**
     * 渲染图片部分的ui
     * @private
     */
    _renderImgList: function _renderImgList() {
      var _this2 = this;

      var h = this.$createElement;
      return h(_descriptions["default"], {
        attrs: {
          column: this.colProp,
          title: this.$props.imgTitle
        }
      }, [this.$props.imgList.map(function (item) {
        return h(ADescriptionsItem, {
          attrs: {
            label: item.title
          }
        }, [_this2._renderSupportForImgList(item)]);
      })]);
    },

    /**
     * 给多张图片特定开的渲染方法
     * @param item
     * @returns {JSX.Element}
     * @private
     */
    _renderSupportForImgList: function _renderSupportForImgList(item) {
      var _this3 = this;

      var h = this.$createElement;

      var imageValue = this._getImgValue(item);

      var imageValueArr = imageValue;

      if (!Array.isArray(imageValueArr)) {
        imageValueArr = [imageValue];
      }

      var imageCount = imageValueArr.length;

      if (imageCount > 1) {
        return h("div", {
          style: "display:inline-block;"
        }, [imageValueArr.map(function (url) {
          return _this3._renderImageItem(url);
        })]);
      } else if (imageCount === 1) {
        return this._renderImageItem(imageValueArr[0]);
      } else {
        return h("span", ["-"]);
      }
    },

    /**
     * 渲染单张图片
     * @param url
     * @returns {JSX.Element}
     * @private
     */
    _renderImageItem: function _renderImageItem(url) {
      var h = this.$createElement;
      // const imgStyle = 'margin: 16px 0px 0px 16px'
      var imgStyle = 'margin: 0 16px 16px 0';
      return this.$props.useOssSTSPolicy ? h(_OssImage["default"], {
        style: imgStyle,
        attrs: {
          url: url,
          ossClient: this.ossClient,
          timeout: this.ossTimeout
        }
      }) : h(_Image["default"], {
        style: imgStyle,
        attrs: {
          url: url
        }
      });
    }
  },
  render: function render() {
    var h = arguments[0];
    var _this$$props = this.$props,
        cardTitle = _this$$props.cardTitle,
        infoList = _this$$props.infoList,
        imgList = _this$$props.imgList;

    if (cardTitle) {
      return h(_card["default"], {
        attrs: {
          title: cardTitle,
          bordered: false
        }
      }, [infoList && infoList.length > 0 ? this._renderInfoList() : null, imgList && imgList.length > 0 ? this._renderImgList() : null, this.$slots["default"] ? this.$slots["default"] : null, h("template", {
        slot: "extra"
      }, [this.$slots['cardExtra']])]);
    } else {
      return h("div", [infoList && infoList.length > 0 ? this._renderInfoList() : null, imgList && imgList.length > 0 ? this._renderImgList() : null, this.$slots["default"] ? this.$slots["default"] : null]);
    }
  }
};
exports["default"] = _default;