"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _types = require("./types");

var _isPromise = _interopRequireDefault(require("is-promise"));

var _select = _interopRequireDefault(require("ant-design-vue/es/select"));

require("./style.less");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

/**
 *  字典列表的下拉选择框
 */
var _default = {
  name: 'EDictSelect',
  props: _types.DictSelectProps,
  data: function data() {
    return {
      // 待下拉数据是否准备完毕
      dataReady: false,
      // 待下拉数据集合
      list: [],
      // 选中的项数据
      selectedValue: undefined
    };
  },
  // 数据双向绑定，定义props的value为双向绑定属性，同时定义selected为抛出事件
  model: {
    props: 'value',
    event: 'selected'
  },
  computed: {
    text: function text() {
      var _this = this;

      var i = this.$data.list && this.$data.list.findIndex(function (item) {
        return item.value === _this.$props.value;
      });

      if (i !== -1) {
        return this.$data.list[i].label;
      } else {
        return '';
      }
    }
  },
  watch: {
    value: function value(newVal) {
      this.$data.selectedValue = newVal;
    }
  },
  created: function created() {
    this.$data.selectedValue = this.$props.value || undefined;
  },
  mounted: function mounted() {
    this._initOptionList();
  },
  methods: {
    /**
     * 初始化选项数据
     * @private
     */
    _initOptionList: function _initOptionList() {
      if (this.$props.options && this.$props.options.length > 0) {
        this.$data.list = this.$props.options;
        this.dataReady = true;
      } else if (this.$props.itemId) {
        this._getItemListByItemID();
      } else {
        this.dataReady = false;
        console.warn('DictSelect传入的数据为空');
      }
    },

    /**
     * 根据字典组id获取字典列表。此方法需要在Vue.use挂载组件的时候被覆盖
     */
    getDictList: function getDictList() {},

    /**
     * 根据字典组ID获取字典列表
     * @private
     */
    _getItemListByItemID: function _getItemListByItemID() {
      var _this2 = this;

      var result = this.getDictList(this.$props.itemId);

      if ((0, _isPromise["default"])(result)) {
        result.then(function (list) {
          _this2.$data.list = list.map(function (item) {
            return {
              label: item.caption,
              value: item.name
            };
          });
          _this2.dataReady = true;
        })["catch"](function () {
          _this2.dataReady = false;
        });
      }
    },

    /**
     * 渲染可编辑的节点
     * @return {JSX.Element}
     * @private
     */
    _renderEditable: function _renderEditable() {
      var _this3 = this;

      var h = this.$createElement;
      return h(_select["default"], {
        attrs: {
          options: this.$data.list,
          value: this.$data.selectedValue,
          disabled: this.$props.disabled,
          placeholder: this.$props.placeholder
        },
        on: {
          "select": function select(value) {
            _this3.$emit('selected', value);
          },
          "change": function change(value) {
            _this3.$data.selectedValue = value;
          }
        }
      });
    },

    /**
     * 渲染不可编辑的节点
     * @return {JSX.Element}
     * @private
     */
    _renderReadOnly: function _renderReadOnly() {
      var h = this.$createElement;
      return h("div", {
        style: "line-height:30px;"
      }, [this.text]);
    }
  },
  render: function render() {
    var h = arguments[0];
    return this.$data.dataReady ? h("div", {
      "class": "dict-select"
    }, [this.$props.editable ? this._renderEditable() : this._renderReadOnly()]) : null;
  }
};
exports["default"] = _default;