"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _babelHelperVueJsxMergeProps = _interopRequireDefault(require("babel-helper-vue-jsx-merge-props"));

var _table = _interopRequireDefault(require("ant-design-vue/es/table"));

var _alert = _interopRequireDefault(require("ant-design-vue/es/alert"));

var _lodash = _interopRequireDefault(require("lodash.get"));

var _types = _interopRequireDefault(require("./types"));

var _constants = require("./constants");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? Object(arguments[i]) : {}; var ownKeys = Object.keys(source); if (typeof Object.getOwnPropertySymbols === 'function') { ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) { return Object.getOwnPropertyDescriptor(source, sym).enumerable; })); } ownKeys.forEach(function (key) { _defineProperty(target, key, source[key]); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

var _default = {
  name: 'ETable',
  props: _types["default"],
  data: function data() {
    return {
      needTotalList: [],
      selectedRows: [],
      selectedRowKeys: [],
      localLoading: false,
      localDataSource: [],
      localPagination: _extends({}, this.pagination)
    };
  },
  watch: {
    'localPagination.current': function localPaginationCurrent(val) {
      this.pageURI && this.$router.push(_objectSpread({}, this.$route, {
        name: this.$route.name,
        params: _extends({}, this.$route.params, {
          pageNo: val
        })
      })); // change pagination, reset total data

      this.needTotalList = this.initTotalList(this.columns);
      this.selectedRowKeys = [];
      this.selectedRows = [];
    },
    pageNum: function pageNum(val) {
      _extends(this.localPagination, {
        current: val
      });
    },
    pageSize: function pageSize(val) {
      _extends(this.localPagination, {
        pageSize: val
      });
    },
    showSizeChanger: function showSizeChanger(val) {
      _extends(this.localPagination, {
        showSizeChanger: val
      });
    }
  },
  created: function created() {
    var pageNo = this.$route.params.pageNo;
    var localPageNum = this.pageURI && pageNo && parseInt(pageNo) || this.pageNum;
    this.localPagination = ['auto', true].includes(this.showPagination) && _extends({}, this.localPagination, {
      current: localPageNum,
      pageSize: this.pageSize,
      showSizeChanger: this.showSizeChanger,
      showQuickJumper: this.showQuickJumper
    }) || false;
    this.needTotalList = this.initTotalList(this.columns);

    if (this.$props.autoLoad) {
      this.loadData();
    }
  },
  methods: {
    /**
     * 表格loading参数修改
     * @param loading
     */
    setLoading: function setLoading(loading) {
      this.localLoading = loading;
    },

    /**
     * 表格重新加载方法
     * 如果参数为 true, 则强制刷新到第一页
     * @param Boolean bool
     */
    refresh: function refresh() {
      var bool = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : false;
      bool && (this.localPagination = _extends({}, {
        current: 1,
        pageSize: this.pageSize
      }));
      this.loadData();
    },

    /**
     * 加载数据方法
     * @param {Object} pagination 分页选项器
     * @param {Object} filters 过滤条件
     * @param {Object} sorter 排序条件
     */
    loadData: function loadData(pagination, filters, sorter) {
      var _this = this;

      this.localLoading = true;
      var pageIndex = pagination && pagination.current || this.showPagination && this.localPagination.current || this.pageNum;

      var parameter = _objectSpread({
        pageIndex: pageIndex,
        pageSize: pagination && pagination.pageSize || this.showPagination && this.localPagination.pageSize || this.pageSize
      }, filters);

      if (sorter && sorter.field && sorter.order && !isNaN(Number(sorter.field))) {
        // 多个字段的排序处理。传入的field必须是一个数字，由后台协议协商固定
        parameter.orderByKeys = [{
          fieldNo: Number(sorter.field),
          index: 0,
          sortType: sorter.order === 'ascend' ? _constants.SORT_TYPE.ASCENDING : _constants.SORT_TYPE.DESCENDING
        }];
      } // console.log('parameter', parameter)


      var result = this.data(parameter); // 对接自己的通用数据接口需要修改下方代码中的 r.pageNo, r.totalCount, r.data
      // eslint-disable-next-line

      if ((typeof result === 'object' || typeof result === 'function') && typeof result.then === 'function') {
        result.then(function (r) {
          var count = r.count,
              list = r.list;
          _this.localPagination = _this.showPagination && _extends({}, _this.localPagination, {
            // current: r.pageNo, // 返回结果中的当前分页数
            // total: r.totalCount, // 返回结果中的总记录数
            current: pageIndex,
            // 返回结果中的当前分页数
            total: count,
            // 返回结果中的总记录数
            showSizeChanger: _this.showSizeChanger,
            pageSize: pagination && pagination.pageSize || _this.localPagination.pageSize
          }) || false; // 为防止删除数据后导致页面当前页面数据长度为 0 ,自动翻页到上一页

          if (list.length === 0 && _this.showPagination && _this.localPagination.current > 1) {
            _this.localPagination.current--;

            _this.loadData();

            return;
          } // 这里用于判断接口是否有返回 r.totalCount 且 this.showPagination = true 且 pageNo 和 pageSize 存在 且 totalCount 小于等于 pageNo * pageSize 的大小
          // 当情况满足时，表示数据不满足分页大小，关闭 table 分页功能


          try {
            if (['auto', true].includes(_this.showPagination) && count <= pageIndex * _this.localPagination.pageSize) {
              _this.localPagination.hideOnSinglePage = true;
            }
          } catch (e) {
            _this.localPagination = false;
          } // console.log('loadData -> this.localPagination', this.localPagination)


          _this.localDataSource = list; // 返回结果中的数组数据

          _this.localLoading = false;
        })["catch"](function () {
          _this.localLoading = false;
        });
      }
    },
    initTotalList: function initTotalList(columns) {
      var totalList = [];
      columns && columns instanceof Array && columns.forEach(function (column) {
        if (column.needTotal) {
          totalList.push(_objectSpread({}, column, {
            total: 0
          }));
        }
      });
      return totalList;
    },

    /**
     * 用于更新已选中的列表数据 total 统计
     * @param selectedRowKeys
     * @param selectedRows
     */
    updateSelect: function updateSelect(selectedRowKeys, selectedRows) {
      this.selectedRows = selectedRows;
      this.selectedRowKeys = selectedRowKeys;
      var list = this.needTotalList;
      this.needTotalList = list.map(function (item) {
        return _objectSpread({}, item, {
          total: selectedRows.reduce(function (sum, val) {
            var total = sum + parseInt((0, _lodash["default"])(val, item.dataIndex));
            return isNaN(total) ? 0 : total;
          }, 0)
        });
      });
    },

    /**
     * 清空 table 已选中项
     */
    clearSelected: function clearSelected() {
      if (this.rowSelection) {
        this.rowSelection.onChange([], []);
        this.updateSelect([], []);
      }
    },

    /**
     * 处理交给 table 使用者去处理 clear 事件时，内部选中统计同时调用
     * @param callback
     * @returns {*}
     */
    renderClear: function renderClear(callback) {
      var _this2 = this;

      var h = this.$createElement;
      if (this.selectedRowKeys.length <= 0) return null;
      return h("a", {
        style: "margin-left: 24px",
        on: {
          "click": function click() {
            callback();

            _this2.clearSelected();
          }
        }
      }, ["\u6E05\u7A7A"]);
    },
    renderAlert: function renderAlert() {
      var h = this.$createElement;
      // 绘制统计列数据
      var needTotalItems = this.needTotalList.map(function (item) {
        return h("span", {
          style: "margin-right: 12px"
        }, [item.title, "\u603B\u8BA1", ' ', h("a", {
          style: "font-weight: 600"
        }, [!item.customRender ? item.total : item.customRender(item.total)])]);
      }); // 绘制 清空 按钮

      var clearItem = typeof this.alert.clear === 'boolean' && this.alert.clear ? this.renderClear(this.clearSelected) : this.alert !== null && typeof this.alert.clear === 'function' ? this.renderClear(this.alert.clear) : null; // 绘制 alert 组件

      return h(_alert["default"], {
        attrs: {
          showIcon: true
        },
        style: "margin-bottom: 16px"
      }, [h("template", {
        slot: "message"
      }, [h("span", {
        style: "margin-right: 12px"
      }, ["\u5DF2\u9009\u62E9: ", h("a", {
        style: "font-weight: 600"
      }, [this.selectedRows.length])]), needTotalItems, clearItem])]);
    }
  },
  render: function render() {
    var _this3 = this;

    var h = arguments[0];
    var props = {};
    var localKeys = Object.keys(this.$data);
    var showAlert = typeof this.alert === 'object' && this.alert !== null && this.alert.show && typeof this.rowSelection.selectedRowKeys !== 'undefined' || this.alert;
    Object.keys(_table["default"].props).forEach(function (k) {
      var localKey = "local".concat(k.substring(0, 1).toUpperCase()).concat(k.substring(1));

      if (localKeys.includes(localKey)) {
        props[k] = _this3[localKey];
        return props[k];
      }

      if (k === 'rowSelection') {
        if (showAlert && _this3.rowSelection) {
          // 如果需要使用alert，则重新绑定 rowSelection 事件
          props[k] = _objectSpread({}, _this3.rowSelection, {
            selectedRows: _this3.selectedRows,
            selectedRowKeys: _this3.selectedRowKeys,
            onChange: function onChange(selectedRowKeys, selectedRows) {
              _this3.updateSelect(selectedRowKeys, selectedRows);

              typeof _this3[k].onChange !== 'undefined' && _this3[k].onChange(selectedRowKeys, selectedRows);
            }
          });
          return props[k];
        } else if (!_this3.rowSelection) {
          // 如果没打算开启 rowSelection 则清空默认的选择项
          props[k] = null;
          return props[k];
        }
      }

      _this3[k] && (props[k] = _this3[k]);
      return props[k];
    }); // console.log('~~~this.$slots~~~', this.$slots)

    var table = h(_table["default"], (0, _babelHelperVueJsxMergeProps["default"])([{
      props: props,
      scopedSlots: _objectSpread({}, this.$scopedSlots)
    }, {
      on: {
        "change": this.loadData,
        "expand": function expand(expanded, record) {
          _this3.$emit('expand', expanded, record);
        }
      }
    }]), [Object.keys(this.$slots).map(function (name) {
      return h("template", {
        slot: name
      }, [_this3.$slots[name]]);
    })]);
    return h("div", {
      "class": "table-wrapper"
    }, [showAlert ? this.renderAlert() : null, table]);
  }
};
exports["default"] = _default;